@@ -162,7 +162,7 @@ void CBarShader::Fill(DWORD color) {
 	m_FirstSpan->color = color;
 }
 
-void CBarShader::Draw(wxMemoryDC* dc, int iLeft, int iTop, bool bFlat) {
+void CBarShader::Draw(wxDC* dc, int iLeft, int iTop, bool bFlat) {
 	BarSpan *bsCurrent = m_FirstSpan;
 	RECT rectSpan;
 	rectSpan.top = iTop;
@@ -213,7 +213,7 @@ void CBarShader::Draw(wxMemoryDC* dc, int iLeft, int iTop, bool bFlat) {
 	///printf(" piirettiin %d palaa. Kesti %d ms. Leveys %d\n",drawnItems,GetTickCount()-now,m_iWidth);
 }
 
-void CBarShader::FillRect(wxMemoryDC *dc, RECT* rectSpan, DWORD color, bool bFlat) {
+void CBarShader::FillRect(wxDC *dc, RECT* rectSpan, DWORD color, bool bFlat) {
   if(rectSpan->right-rectSpan->left<1)
     return;
 
@@ -229,7 +229,7 @@ void CBarShader::FillRect(wxMemoryDC *dc, RECT* rectSpan, DWORD color, bool bFla
   }
 }
 
-void CBarShader::FillRect(wxMemoryDC *dc, RECT* rectSpan, float fRed, float fGreen,
+void CBarShader::FillRect(wxDC *dc, RECT* rectSpan, float fRed, float fGreen,
 						  float fBlue, bool bFlat) {
   if(rectSpan->right-rectSpan->left<1)
     return;
