@@ -83,7 +83,7 @@ CUpDownClient::CUpDownClient(uint16 in_port, uint32 in_userid,uint32 in_serverip
 void CUpDownClient::Init(){
 	memset(m_szFullUserIP,0,21);
 	credits = 0;
-	memset(reqfileid, 0, sizeof reqfileid);
+	memset(requpfileid, 0, sizeof requpfileid);
 	m_nAvDownDatarate = 0;
 	m_nAvUpDatarate = 0;
 	m_byChatstate = 0;
@@ -103,7 +103,7 @@ void CUpDownClient::Init(){
 	m_nUserID = 0;
 	m_nServerPort = 0;
 	m_bBanned = false;
-	m_bFileListRequested = false;
+	m_iFileListRequested = 0;
 	m_dwLastUpRequest = 0;
 	m_bEmuleProtocol = false;
 	usedcompressiondown = false;
@@ -163,6 +163,7 @@ void CUpDownClient::Init(){
 		strcpy(m_szFullUserIP,inet_ntoa(sockAddr.sin_addr));
 	}
 	sourcesslot=0;
+	m_bHashsetRequested=false;
 	// At the beginning, client is't a thief :)
 	leechertype = 0;
 	thief = false;
@@ -223,6 +224,7 @@ CUpDownClient::~CUpDownClient(){
 	m_AvarageUDR_list.RemoveAll();
 	m_AvarageDDR_list.RemoveAll();
 	//DEBUG_ONLY (theApp.listensocket->Debug_ClientDeleted(this));
+	SetUploadFileID(NULL);
 }
 
 void CUpDownClient::ProcessHelloPacket(char* pachPacket, uint32 nSize){
@@ -579,7 +581,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer){
 	tag2.WriteTagToFile(data);
 	CTag tag3(ET_UDPPORT,theApp.glob_prefs->GetUDPPort());
 	tag3.WriteTagToFile(data);
-	CTag tag4(ET_SOURCEEXCHANGE,1);
+	CTag tag4(ET_SOURCEEXCHANGE,2);
 	tag4.WriteTagToFile(data);
 	CTag tag5(ET_COMMENTS,1);
 	tag5.WriteTagToFile(data);
@@ -948,9 +950,9 @@ void CUpDownClient::Disconnected(){
 	  //delete socket;
 	}
 	socket = 0;
-	if (m_bFileListRequested){
+	if (m_iFileListRequested){
 		theApp.xmuledlg->AddDebugLogLine(false,GetResString(IDS_SHAREDFILES_FAILED),GetUserName());
-		m_bFileListRequested = false;
+		m_iFileListRequested = 0;
 	}
 	if (m_Friend)
 	  theApp.friendlist->RefreshFriend(m_Friend);
@@ -1067,8 +1069,8 @@ void CUpDownClient::ConnectionEstablished(){
 				socket->SendPacket(packet,true);
 			}
 	}
-	if (m_bFileListRequested){
-		Packet* packet = new Packet(OP_ASKSHAREDFILES,0);
+	if (m_iFileListRequested==1){
+		Packet* packet = new Packet((GetClientSoft()==SO_EDONKEYHYBRID) ? OP_ASKSHAREDDIRS : OP_ASKSHAREDFILES,0);
 		theApp.uploadqueue->AddUpDataOverheadOther(packet->size);
 		socket->SendPacket(packet,true,true);
 	}
@@ -1144,13 +1146,13 @@ void CUpDownClient::SetUserName(char* pszNewName){
 
 void CUpDownClient::RequestSharedFileList(){
 	theApp.xmuledlg->AddDebugLogLine(true,GetResString(IDS_SHAREDFILES_REQUEST),GetUserName());
-	m_bFileListRequested = true;
+	m_iFileListRequested = 1;
 	TryToConnect(true);
 }
 
 void CUpDownClient::ProcessSharedFileList(char* pachPacket, uint32 nSize){
-	if (m_bFileListRequested){
-		m_bFileListRequested = false;
+	if (m_iFileListRequested>0){
+		m_iFileListRequested--;
 		theApp.searchlist->ProcessSearchanswer(pachPacket,nSize,this);
 	}
 }
