@@ -162,7 +162,7 @@ BOOL CClientDetailDialog::OnInitDialog(){
 		GetDlgItem(ID_DSNAME,wxStaticText)->SetLabel("?");
 	}
 
-	CKnownFile* file = theApp.sharedfiles->GetFileByID(m_client->reqfileid);
+	CKnownFile* file = theApp.sharedfiles->GetFileByID(m_client->GetUploadFileID());
 	if (file)
 		GetDlgItem(ID_DDOWNLOADING,wxStaticText)->SetLabel(file->GetFileName());
 	else
