@@ -250,6 +250,7 @@ void CUpDownClient::ProcessFileStatus(char* packet,uint32 size){
 		socket->SendPacket(packet, true, true);
 		SetDownloadState(DS_REQHASHSET);
 		reqfile->hashsetneeded = false;
+		m_bHashsetRequested = true;
 	}
 	else{
 		SetDownloadState(DS_ONQUEUE);
@@ -338,7 +339,10 @@ void CUpDownClient::SetDownloadState(uint8 byNewState){
 
 void CUpDownClient::ProcessHashSet(char* packet,uint32 size){
 	if ( (!reqfile) || memcmp(packet,reqfile->GetFileHash(),16))
-		throw CString(GetResString(IDS_ERR_WRONGFILEID)+" (ProcessHashSet)");	
+		throw CString(GetResString(IDS_ERR_WRONGFILEID)+" (ProcessHashSet)");
+	if ( !m_bHashsetRequested )
+		throw CString(_("Received unsolicited hashset, ignoring it."));
+	m_bHashsetRequested = false;
 	CSafeMemFile* data = new CSafeMemFile((BYTE*)packet,size);
 	if (reqfile->LoadHashsetFromFile(data,true)){
 	}
@@ -966,6 +970,7 @@ bool CUpDownClient::SwapToAnotherFile()
 			CPartFile* cur_file = this->m_OtherRequests_list.GetAt(pos2);
 			if (cur_file != this->reqfile
 			&& theApp.downloadqueue->IsPartFile(cur_file)
+			&& !cur_file->IsStopped()
 			&& (cur_file->GetStatus(false) == PS_READY || cur_file->GetStatus(false) == PS_EMPTY))
 			{
 				SwapTo = cur_file;
@@ -1035,3 +1040,12 @@ bool CUpDownClient::SwapToAnotherFile()
 }
 
 /* End modif */
+
+void CUpDownClient::SetDownloadFile(CPartFile *part)
+{
+	delete[] m_abyPartStatus;
+	m_abyPartStatus = NULL;
+	m_nPartCount = 0;
+
+	reqfile = part;
+}
