@@ -176,7 +176,7 @@ void CDownloadListCtrl::HideSources(CPartFile * toCollapse, bool isShift, bool i
 		if (item->owner == toCollapse) {
 			pre++;
 			CUpDownClient *cl = (CUpDownClient*)item->value;
-			if ((isShift || isCtrl || isAlt) && (cl->reqfile == toCollapse)) {
+			if ((isShift || isCtrl || isAlt) && (cl->GetDownloadFile() == toCollapse)) {
 				uint8 ds = cl->GetDownloadState();
 				if ((isShift && ds == DS_DOWNLOADING) || (isCtrl && cl->GetRemoteQueueRank() > 0) || (isAlt && ds != DS_NONEEDEDPARTS)) {
 					continue;
@@ -226,12 +226,12 @@ void CDownloadListCtrl::setPri(int newpri)
 			CPartFile *file = (CPartFile *) content->value;
 			if (selectedCount > 1) {
 				while (!selectedList.IsEmpty()) {
-					selectedList.GetHead()->SetPriority(newpri);
+					selectedList.GetHead()->SetDownPriority(newpri);
 					selectedList.RemoveHead();
 				}
 				return;
 			}
-			file->SetPriority(newpri);
+			file->SetDownPriority(newpri);
 		}
 	}
 }
@@ -425,9 +425,10 @@ void CDownloadListCtrl::OnNMRclick(wxListEvent & evt)
 			menu->Enable(MP_CANCEL, MF_ENABLED);
 
 			wxMenu *priomenu = m_PrioMenu;
-			priomenu->Check(MP_PRIOHIGH, (file->GetPriority() == PR_HIGH) ? MF_CHECKED : MF_UNCHECKED);
-			priomenu->Check(MP_PRIONORMAL, (file->GetPriority() == PR_NORMAL) ? MF_CHECKED : MF_UNCHECKED);
-			priomenu->Check(MP_PRIOLOW, (file->GetPriority() == PR_LOW) ? MF_CHECKED : MF_UNCHECKED);
+			priomenu->Check(MP_PRIOHIGH, (!file->IsAutoDownPriority() && (file->GetDownPriority() == PR_HIGH)) ? MF_CHECKED : MF_UNCHECKED);
+			priomenu->Check(MP_PRIONORMAL, (!file->IsAutoDownPriority() && (file->GetDownPriority() == PR_NORMAL)) ? MF_CHECKED : MF_UNCHECKED);
+			priomenu->Check(MP_PRIOLOW, (!file->IsAutoDownPriority() && (file->GetDownPriority() == PR_LOW)) ? MF_CHECKED : MF_UNCHECKED);
+			priomenu->Check(MP_PRIOAUTO, file->IsAutoDownPriority() ? MF_CHECKED : MF_UNCHECKED);
 
 			PopupMenu(m_FileMenu, evt.GetPoint());
 		} else {
@@ -458,7 +459,7 @@ void CDownloadListCtrl::OnColResize(wxListEvent & evt)
 void CDownloadListCtrl::OnDrawItem(int item, wxDC * dc, const wxRect & rect, const wxRect & rectHL, bool highlighted)
 {
 	/* Don't do any drawing if there's nobody to see it. */
-	if (theApp.xmuledlg->GetActiveDialog() != 2) {
+	if (!theApp.xmuledlg->IsRunning() || (theApp.xmuledlg->GetActiveDialog() != 2)) {
 		return;
 	}
 	CtrlItem_Struct *content = (CtrlItem_Struct *) GetItemData(item);
@@ -885,7 +886,7 @@ void CDownloadListCtrl::AddSource(CPartFile * owner, CUpDownClient * source, boo
 		return;
 	}
 	if (owner->m_bShowOnlyDownloading &&
-	    ((source->GetDownloadState() != DS_DOWNLOADING) || (source->reqfile!=owner))) {
+	    ((source->GetDownloadState() != DS_DOWNLOADING) || (source->GetDownloadFile()!=owner))) {
 		return;
 	}
 	// insert newitem to the display too!
@@ -1099,48 +1100,31 @@ void CDownloadListCtrl::DrawFileItem(wxDC * dc, int nColumn, LPRECT lpRect, Ctrl
 						buffer2 = "";
 					}
 					buffer.Format("%s%i (%i)", buffer2.GetData(), lpPartFile->GetSourceCount(), lpPartFile->GetTransferingSrcCount());
-					//UAP
-					if (((CKnownFile *) lpPartFile)->IsAutoPrioritized()) {
-						((CKnownFile *) lpPartFile)->UpdateUploadAutoPriority();
-					}
-					theApp.sharedfiles->UpdateItem(((CKnownFile *) lpPartFile));
-					//end UAP
 					dc->DrawText(buffer, lpRect->left, lpRect->top);
 				}
 				break;
 
 			case 7:	// prio
-				if ((lpPartFile->IsAutoPrioritized()) && (theApp.glob_prefs->GetNewAutoUp())) {	//Hunter
-					if ((lpPartFile->GetSourceCount() <= 100) && (lpPartFile->GetPriority() != PR_HIGH)) {
-						lpPartFile->SetPriority(PR_HIGH);
-					} else if ((lpPartFile->GetSourceCount() > 100) && (lpPartFile->GetSourceCount() <= 300) && (lpPartFile->GetPriority() != PR_NORMAL)) {
-						lpPartFile->SetPriority(PR_NORMAL);
-					} else if ((lpPartFile->GetSourceCount() > 300) && (lpPartFile->GetPriority() != PR_LOW)) {
-						lpPartFile->SetPriority(PR_LOW);
-					}
-					switch (lpPartFile->GetPriority()) {
-						case PR_LOW:
-							dc->DrawText(GetResString(IDS_PRIOAUTOLOW), lpRect->left, lpRect->top);
-							break;
-						case PR_NORMAL:
-							dc->DrawText(GetResString(IDS_PRIOAUTONORMAL), lpRect->left, lpRect->top);
-							break;
-						case PR_HIGH:
-							dc->DrawText(GetResString(IDS_PRIOAUTOHIGH), lpRect->left, lpRect->top);
-							break;
-					}
-				} else {
-					switch (lpPartFile->GetPriority()) {
-						case 0:
-							dc->DrawText(GetResString(IDS_PRIOLOW), lpRect->left, lpRect->top);
-							break;
-						case 1:
-							dc->DrawText(GetResString(IDS_PRIONORMAL), lpRect->left, lpRect->top);
-							break;
-						case 2:
-							dc->DrawText(GetResString(IDS_PRIOHIGH), lpRect->left, lpRect->top);
-							break;
-					}
+				switch(lpPartFile->GetDownPriority()) {
+				case PR_LOW:
+					if ( lpPartFile->IsAutoDownPriority() )
+						dc->DrawText(GetResString(IDS_PRIOAUTOLOW), lpRect->left, lpRect->top);
+					else
+						dc->DrawText(GetResString(IDS_PRIOLOW), lpRect->left, lpRect->top);
+					break;
+
+				case PR_NORMAL:
+					if ( lpPartFile->IsAutoDownPriority() )
+						dc->DrawText(GetResString(IDS_PRIOAUTONORMAL), lpRect->left, lpRect->top);
+					else
+						dc->DrawText(GetResString(IDS_PRIONORMAL), lpRect->left, lpRect->top);
+					break;
+				case PR_HIGH:
+					if ( lpPartFile->IsAutoDownPriority() )
+						dc->DrawText(GetResString(IDS_PRIOAUTOHIGH), lpRect->left, lpRect->top);
+					else
+						dc->DrawText(GetResString(IDS_PRIOHIGH), lpRect->left, lpRect->top);
+					break;
 				}
 				break;
 
@@ -1204,6 +1188,8 @@ void CDownloadListCtrl::DrawFileItem(wxDC * dc, int nColumn, LPRECT lpRect, Ctrl
 void CDownloadListCtrl::DrawSourceItem(wxDC * dc, int nColumn, LPRECT lpRect, CtrlItem_Struct * lpCtrlItem)
 {
 	if (lpRect->left < lpRect->right) {
+		// force clipper (clip 2 px more than the rectangle from the right side)
+		wxDCClipper clipper(*dc, lpRect->left, lpRect->top, lpRect->right - lpRect->left - 2, lpRect->bottom - lpRect->top);
 
 		CString buffer;
 		CUpDownClient *lpUpDownClient = (CUpDownClient *) lpCtrlItem->value;
@@ -1484,7 +1470,7 @@ void CDownloadListCtrl::OnLvnItemActivate(wxListEvent & evt)
 					partfile->m_bShowOnlyDownloading = isShift;
 					if (isShift) {
 						uint8 ds = client->GetDownloadState();
-						if ((client->reqfile != partfile) || (ds != DS_DOWNLOADING)) {
+						if ((client->GetDownloadFile() != partfile) || (ds != DS_DOWNLOADING)) {
 							continue;
 						}
 					}
@@ -1749,55 +1735,57 @@ bool CDownloadListCtrl::ProcessEvent(wxEvent & evt)
 					if (selectedCount > 1) {
 						Freeze();
 						while (!selectedList.IsEmpty()) {
-							selectedList.GetHead()->SetAutoPriority(false);	//[Tarod]
-							selectedList.GetHead()->SetPriority(PR_HIGH);
+							selectedList.GetHead()->SetAutoDownPriority(false);	//[Tarod]
+							selectedList.GetHead()->SetDownPriority(PR_HIGH);
 							selectedList.RemoveHead();
 						}
 						Thaw();
 						break;
 					}
-					file->SetAutoPriority(false);
-					file->SetPriority(PR_HIGH);
+					file->SetAutoDownPriority(false);
+					file->SetDownPriority(PR_HIGH);
 					break;
 				case MP_PRIOLOW:
 					if (selectedCount > 1) {
 						Freeze();
 						while (!selectedList.IsEmpty()) {
-							selectedList.GetHead()->SetAutoPriority(false);	//[Tarod]
-							selectedList.GetHead()->SetPriority(PR_LOW);
+							selectedList.GetHead()->SetAutoDownPriority(false);	//[Tarod]
+							selectedList.GetHead()->SetDownPriority(PR_LOW);
 							selectedList.RemoveHead();
 						}
 						Thaw();
 						break;
 					}
-					file->SetAutoPriority(false);
-					file->SetPriority(PR_LOW);
+					file->SetAutoDownPriority(false);
+					file->SetDownPriority(PR_LOW);
 					break;
 				case MP_PRIONORMAL:
 					if (selectedCount > 1) {
 						Freeze();
 						while (!selectedList.IsEmpty()) {
-							selectedList.GetHead()->SetAutoPriority(false);	//[Tarod]
-							selectedList.GetHead()->SetPriority(PR_NORMAL);
+							selectedList.GetHead()->SetAutoDownPriority(false);	//[Tarod]
+							selectedList.GetHead()->SetDownPriority(PR_NORMAL);
 							selectedList.RemoveHead();
 						}
 						Thaw();
 						break;
 					}
-					file->SetAutoPriority(false);
-					file->SetPriority(PR_NORMAL);
+					file->SetAutoDownPriority(false);
+					file->SetDownPriority(PR_NORMAL);
 					break;
 				case MP_PRIOAUTO:
 					if (selectedCount > 1) {
 						Freeze();
 						while (!selectedList.IsEmpty()) {
-							selectedList.GetHead()->SetPriority(PR_AUTO);
+							selectedList.GetHead()->SetAutoDownPriority(true);
+							selectedList.GetHead()->SetDownPriority(PR_HIGH);
 							selectedList.RemoveHead();
 						}
 						Thaw();
 						break;
 					}
-					file->SetPriority(PR_AUTO);
+					file->SetAutoDownPriority(true);
+					file->SetDownPriority(PR_HIGH);
 					break;
 				case MP_PAUSE:
 					if (selectedCount > 1) {
@@ -2078,7 +2066,7 @@ int CDownloadListCtrl::Compare(CPartFile * file1, CPartFile * file2, long lParam
 		case 6:	//sources asc
 			return file1->GetSourceCount() - file2->GetSourceCount();
 		case 7:	//priority asc
-			return file1->GetPriority() - file2->GetPriority();
+			return file1->GetDownPriority() - file2->GetDownPriority();
 		case 8:	//Status asc 
 			return file1->getPartfileStatusRang() - file2->getPartfileStatusRang();
 		case 9:	//Remaining Time asc 
