@@ -45,6 +45,7 @@ CDownloadQueue::CDownloadQueue(CPreferences* in_prefs,CSharedFileList* in_shared
 	m_nDownDataOverheadOtherPackets = 0;
 	m_nDownDataOverheadServerPackets = 0;
 	m_nLastED2KLinkCheck = 0;
+	m_lastRefreshedDLDisplay = 0;
 }
 
 void CDownloadQueue::UpdateDisplayedInfo(bool force) {
@@ -188,12 +189,12 @@ void CDownloadQueue::StartNextFile(){
 		if (cur_file->GetStatus() == PS_PAUSED){
 			if (!pfile){
 				pfile = cur_file;
-				if (pfile->GetPriority() == PR_HIGH) break;
+				if (pfile->GetDownPriority() == PR_HIGH) break;
 			}
 			else{
-				if (cur_file->GetPriority() > pfile->GetPriority()){
+				if (cur_file->GetDownPriority() > pfile->GetDownPriority()){
 					pfile = cur_file;
-					if (pfile->GetPriority() == PR_HIGH) break;
+					if (pfile->GetDownPriority() == PR_HIGH) break;
 				}
 			}
 		}
@@ -213,10 +214,10 @@ void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink* pLink) {
 	}
 	if (pLink->HasValidSources()) {
 		if (newfile) { // Bodo: "no return?" seems to be ok...
-			newfile->AddClientSources(pLink->SourcesList);
+			newfile->AddClientSources(pLink->SourcesList,1);
 		} else {
 				CPartFile* partfile = GetFileByID((uchar*)pLink->GetHashKey());
-				if (partfile) partfile->AddClientSources(pLink->SourcesList);
+				if (partfile) partfile->AddClientSources(pLink->SourcesList,1);
 		}
 	}
 }
@@ -265,19 +266,19 @@ void CDownloadQueue::Process(){
 	datarate = 0;
 	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
 		CPartFile* cur_file =  filelist.GetAt(pos);
-		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && cur_file->GetPriority() == PR_HIGH){
+		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (!cur_file->IsAutoDownPriority() && cur_file->GetDownPriority() == PR_HIGH)){
 			datarate += cur_file->Process(downspeed);
 		}
 	}
 	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
 		CPartFile* cur_file =  filelist.GetAt(pos);
-		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && cur_file->GetPriority() == PR_NORMAL){
+		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (!cur_file->IsAutoDownPriority() && cur_file->GetDownPriority() == PR_NORMAL)){
 			datarate += cur_file->Process(downspeed);
 		}
 	}
 	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
 		CPartFile* cur_file =  filelist.GetAt(pos);
-		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (cur_file->GetPriority() == PR_LOW || cur_file->GetPriority() == PR_AUTO )){
+		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (cur_file->GetDownPriority() == PR_LOW || cur_file->IsAutoDownPriority())){
 			datarate += cur_file->Process(downspeed);
 		}
 	}
@@ -373,7 +374,7 @@ void CDownloadQueue::CheckAndAddSource(CPartFile* sender,CUpDownClient* source){
 	//if yes the known client will be attached to the var "source"
 	//and the old sourceclient will be deleted
 	if (theApp.clientlist->AttachToAlreadyKnown(&source,0))
-		source->reqfile = sender;
+		source->SetDownloadFile(sender);
 	else
 		theApp.clientlist->AddClient(source,true);
 
@@ -399,7 +400,7 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile* sender,CUpDownClient* sou
 			return;
 		}
 	}
-	source->reqfile = sender;
+	source->SetDownloadFile(sender);
 	sender->srclists[source->sourcesslot].AddTail(source);
 	theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,false);
 	UpdateDisplayedInfo();
@@ -433,7 +434,7 @@ bool CDownloadQueue::RemoveSource(CUpDownClient* toremove, bool	updatewindow){
 					toremove->SetDownloadState(DS_NONE);
 					theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(toremove, cur_file);
 				}
-				toremove->reqfile = NULL;
+				toremove->SetDownloadFile(NULL);
 				/* End modif */
 				break;
 			}
@@ -444,7 +445,7 @@ bool CDownloadQueue::RemoveSource(CUpDownClient* toremove, bool	updatewindow){
 		toremove->SetDownloadState(DS_NONE);
 		theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(toremove,0);
 	}
-	toremove->reqfile = 0;
+	toremove->SetDownloadFile(NULL);
 	return removed;
 }
 
@@ -531,11 +532,11 @@ void CDownloadQueue::SortByPriority(){
    for( pos1 = filelist.GetHeadPosition(); ( pos2 = pos1 ) != NULL; ){
 	   filelist.GetNext(pos1);
 	   CPartFile* cur_file = filelist.GetAt(pos2);
-	   if (cur_file->GetPriority() == PR_HIGH){
+	   if (cur_file->GetDownPriority() == PR_HIGH){
 		   filelist.AddHead(cur_file);
 		   filelist.RemoveAt(pos2);
 	   }
-	   else if (cur_file->GetPriority() == PR_LOW){
+	   else if (cur_file->GetDownPriority() == PR_LOW){
 		   filelist.AddTail(cur_file);
 		   filelist.RemoveAt(pos2);
 	   }
@@ -633,7 +634,7 @@ void CDownloadQueue::RemoveSourceFromPartFile(CPartFile* file, CUpDownClient* cl
 	// Remove source of download list window
 	theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(client, file);
 	// Set requested file of client to 0
-	client->reqfile = 0;
+	client->SetDownloadFile(NULL);
 	// If other requests list of client isn't empty...
 	if(! client->m_OtherRequests_list.IsEmpty()) {
 		// Some positions
@@ -697,12 +698,12 @@ void CDownloadQueue::SetCatPrio(int cat, uint8 newprio){
 		CPartFile* cur_file = filelist.GetAt(pos);
 		if (cat==0 || cur_file->GetCategory()==cat) {
 			if (newprio==PR_AUTO) {
-				cur_file->SetAutoPriority(true);
-				cur_file->SetPriority(PR_HIGH);
+				cur_file->SetAutoDownPriority(true);
+				cur_file->SetDownPriority(PR_HIGH);
 			}
 			else {
-				cur_file->SetAutoPriority(false);
-				cur_file->SetPriority(newprio);
+				cur_file->SetAutoDownPriority(false);
+				cur_file->SetDownPriority(newprio);
 			}
 		}
 	}
