@@ -147,7 +147,13 @@ void CPartFile::Init(){
 	stopped = false;
 	SetPartFileStatus(PS_EMPTY);
 	transfered = 0;
-	priority = PR_NORMAL;
+	if(theApp.glob_prefs->GetNewAutoDown()){
+		m_iDownPriority = PR_HIGH;
+		m_bAutoDownPriority = true;
+	} else {
+		m_iDownPriority = PR_NORMAL;
+		m_bAutoDownPriority = false;
+	}
 	srcarevisible = false;
 	transferingsrc = 0;
 	datarate = 0;
@@ -161,7 +167,6 @@ void CPartFile::Init(){
 	availablePartsCount=0;
 	m_ClientSrcAnswered = 0;
 	m_LastNoNeededCheck = 0;
-	m_bAutoPriority = false ; 
 	m_iRate = 0;
 	m_strComment = "";
 	m_nTotalBufferData = 0;
@@ -208,7 +213,7 @@ void CPartFile::CreatePartFile(){
 	
 	}while(wxFileName::FileExists(filename)); 
 	partmetfilename = new char[15]; 
-	sprintf(partmetfilename,"%03i.part.met",i); 
+	sprintf(partmetfilename,"%03i.part.met",i);
 
 	fullname = new char[strlen(theApp.glob_prefs->GetTempDir())+strlen(partmetfilename)+MAX_PATH];
 	sprintf(fullname,"%s/%s",theApp.glob_prefs->GetTempDir(),partmetfilename);
@@ -242,14 +247,6 @@ void CPartFile::CreatePartFile(){
 	for (uint32 i = 0; i != GetPartCount();i++)
 		m_SrcpartFrequency.Add(0);
 	paused = false;
-	//UAP Hunter
-	if (theApp.glob_prefs->GetNewAutoUp())
-		((CKnownFile*)this)->SetAutoPriority(true);
-	else
-		((CKnownFile*)this)->SetAutoPriority(false);
-
-	((CKnownFile*)this)->UpdateUploadAutoPriority();
-	//end UAP
 	SavePartFile(true);
 }
 
@@ -326,15 +323,17 @@ bool CPartFile::LoadPartFile(char* in_directory,char* in_filename){
 				    delete newtag;
 				    break;
 				}
-				case FT_PRIORITY:{
-				    priority = newtag->tag->intvalue;
-				    if ((priority==PR_AUTO)&&(!theApp.glob_prefs->GetNewAutoUp())) priority=PR_NORMAL;
-				    delete newtag;
-				    if (priority == PR_AUTO)
-					this->SetAutoPriority(true);
-				    else
-					this->SetAutoPriority(false);
-				    break;
+				case FT_OLDDLPRIORITY:
+				case FT_DLPRIORITY:{
+					m_iDownPriority = newtag->tag->intvalue;
+					delete newtag;
+					if( m_iDownPriority == PR_AUTO ){
+						m_iDownPriority = PR_HIGH;
+						SetAutoDownPriority(true);
+					}
+					else
+						SetAutoDownPriority(false);
+					break;
 				}
 				case FT_STATUS:{
 				    paused = newtag->tag->intvalue;
@@ -342,17 +341,17 @@ bool CPartFile::LoadPartFile(char* in_directory,char* in_filename){
 				    delete newtag;
 				    break;
 				}
-				case FT_ULPRIORITY:{ 
-				    if ((priority==PR_AUTO)&&(!theApp.glob_prefs->GetNewAutoUp())) priority=PR_NORMAL;
-				    if ((uint8)newtag->tag->intvalue == PR_AUTO) {
-					((CKnownFile*)this)->SetAutoPriority(true);
-					((CKnownFile*)this)->UpdateUploadAutoPriority();
-				    } else {
-					((CKnownFile*)this)->SetAutoPriority(false);
-					((CKnownFile*)this)->SetPriority((uint8)newtag->tag->intvalue);
-				    }
-				    delete newtag;
-				    break; 
+				case FT_OLDULPRIORITY:
+				case FT_ULPRIORITY:{
+					SetUpPriority(newtag->tag->intvalue, false);
+					delete newtag;
+					if( GetUpPriority() == PR_AUTO ){
+						SetUpPriority(PR_HIGH, false);
+						SetAutoUpPriority(true);
+					}
+					else
+						SetAutoUpPriority(false);
+					break;
 				}
 				default:{
 				    // Start Changes by Slugfiller for better exception handling
@@ -415,7 +414,10 @@ bool CPartFile::LoadPartFile(char* in_directory,char* in_filename){
 	if(strcasecmp(strrchr(fullname, '.'), ".backup") == 0) {
 		char *shorten = strrchr(fullname, '.');
 		*shorten = 0;
-		fullname = (char*)realloc(fullname, strlen(fullname) + 1);
+		char *oldfullname = fullname;
+		fullname = new char[strlen(fullname)+1];
+		strcpy(fullname, oldfullname);
+		delete[] oldfullname;
 	}
 
 	// open permanent handle
@@ -426,27 +428,23 @@ bool CPartFile::LoadPartFile(char* in_directory,char* in_filename){
 		delete[] searchpath;
 		return false;
 	}
-			
+	delete[] searchpath; searchpath = NULL;
 
 	m_SrcpartFrequency.SetSize(GetPartCount());
 	for (uint32 i = 0; i != GetPartCount();i++)
 		m_SrcpartFrequency.Add(0);
-	SetPartFileStatus(PS_READY);
+	SetPartFileStatus(PS_EMPTY);
 	// check hashcount, filesatus etc
 	if (hashlist.GetCount() < GetPartCount()){
-		SetPartFileStatus(PS_EMPTY);
 		hashsetneeded = true;
 		return true;
 	}
 	else {
 		hashsetneeded = false;
-		bool empty = true;
 		for (int i = 0; i != hashlist.GetSize(); i++){
 			if (IsComplete(i*PARTSIZE,((i+1)*PARTSIZE)-1))
-				empty = false;
+				SetPartFileStatus(PS_READY);
 		}
-		if (empty)
-			SetPartFileStatus(PS_EMPTY);
 	}
 
 	if (gaplist.IsEmpty()){	// is this file complete already?
@@ -464,9 +462,11 @@ bool CPartFile::LoadPartFile(char* in_directory,char* in_filename){
 			// rehash
 			SetPartFileStatus(PS_WAITINGFORHASH);
 
-			CAddFileThread::AddFile(directory, searchpath, this);
+			char *partfilename = nstrdup(partmetfilename);
+			partfilename[strlen(partfilename)-4] = 0;
+			CAddFileThread::AddFile(directory, partfilename, this);
+			delete[] partfilename;
 		}
-	delete[] searchpath;
 
 	UpdateCompletedInfos();
 	if ( completedsize > transfered )
@@ -499,7 +499,7 @@ bool CPartFile::SavePartFile(bool Initial){
 		searchpath[strlen(fullname)-4] = 0;
 		//bool end = !ff.FindFile(searchpath,0);
 		wxString fName=::wxFindFirstFile(searchpath,wxFILE);
-		delete[] searchpath;
+		delete[] searchpath; searchpath = NULL;
 		//if (!end)
 		//		ff.FindNextFile();
 		//if (end || ff.IsDirectory())
@@ -538,7 +538,7 @@ bool CPartFile::SavePartFile(bool Initial){
 		for (int x = 0; x != parts; x++)
 			fwrite(hashlist[x],16,1,file);
 		//tags
-		uint32 tagcount = taglist.GetCount()+8+(gaplist.GetCount()*2);
+		uint32 tagcount = taglist.GetCount()+10+(gaplist.GetCount()*2);
 		fwrite(&tagcount,4,1,file);
 
 		CTag(FT_FILENAME,m_pszFileName).WriteTagToFile(file);	// 1
@@ -546,35 +546,44 @@ bool CPartFile::SavePartFile(bool Initial){
 		CTag(FT_TRANSFERED,transfered).WriteTagToFile(file);	// 3
 		CTag(FT_STATUS,(paused)? 1:0).WriteTagToFile(file);	// 4
 
-		//UAP Hunter
-		CTag* prioritytag ;
-		if (IsAutoPrioritized()) {
-			uint8 aux_priority = PR_AUTO ;
-			prioritytag = new CTag(FT_PRIORITY,aux_priority);
-		}
+		CTag* prioritytag;
+		uint8 autoprio = PR_AUTO;
+		if( this->IsAutoDownPriority() )
+			prioritytag = new CTag(FT_DLPRIORITY,autoprio);
 		else
-			prioritytag = new CTag(FT_PRIORITY,priority);
+			prioritytag = new CTag(FT_DLPRIORITY,m_iDownPriority);
 		prioritytag->WriteTagToFile(file);			// 5
 		delete prioritytag;
-		//end UAP
+		if( this->IsAutoDownPriority() )
+			prioritytag = new CTag(FT_OLDDLPRIORITY,autoprio);
+		else
+			prioritytag = new CTag(FT_OLDDLPRIORITY,m_iDownPriority);
+		prioritytag->WriteTagToFile(file);			// 6
+		delete prioritytag;
+		
 		
 		CTag* lsctag = new CTag(FT_LASTSEENCOMPLETE,lsc);
-		lsctag->WriteTagToFile(file);				// 6
+		lsctag->WriteTagToFile(file);				// 7
 		delete lsctag;
 
-		// Modified by Tarod for UAP
 		CTag* ulprioritytag;
-		if (((CKnownFile*)this)->IsAutoPrioritized())
-			ulprioritytag = new CTag(FT_ULPRIORITY, PR_AUTO);
+		if( this->IsAutoUpPriority() )
+			ulprioritytag = new CTag(FT_ULPRIORITY,autoprio);
 		else
-			ulprioritytag = new CTag(FT_ULPRIORITY,m_iPriority);
-		ulprioritytag->WriteTagToFile(file);			// 7
+			ulprioritytag = new CTag(FT_ULPRIORITY,GetUpPriority());
+		ulprioritytag->WriteTagToFile(file);			// 8
 		delete ulprioritytag;
-		// End by Tarod
+		if( this->IsAutoUpPriority() )
+			ulprioritytag = new CTag(FT_OLDULPRIORITY,autoprio);
+		else
+			ulprioritytag = new CTag(FT_OLDULPRIORITY,GetUpPriority());
+		ulprioritytag->WriteTagToFile(file);			// 9
+		delete ulprioritytag;
+		
 		
 		// Madcat - Category setting.
 		CTag* categorytab = new CTag(FT_CATEGORY,m_category);
-		categorytab->WriteTagToFile(file);			// 8
+		categorytab->WriteTagToFile(file);			// 10
 		delete categorytab;
 
 		for (uint32 j = 0; j != (uint32)taglist.GetCount();j++)
@@ -842,9 +851,13 @@ void CPartFile::UpdateCompletedInfos()
 {
    	uint32 allgaps = 0; 
 
-	for (POSITION pos = gaplist.GetHeadPosition(); pos != 0; gaplist.GetNext(pos)){ 
-		Gap_Struct* cur_gap = gaplist.GetAt(pos); 
-		allgaps += cur_gap->end - cur_gap->start;
+	for (POSITION pos = gaplist.GetHeadPosition(); pos != 0; ){
+		POSITION prev = pos;
+		Gap_Struct* cur_gap = gaplist.GetNext(pos);
+		if ( (cur_gap->end > m_nFileSize) || (cur_gap->start >= m_nFileSize) )
+			gaplist.RemoveAt(prev);
+		else
+			allgaps += cur_gap->end - cur_gap->start;
 	}
 
 	if (gaplist.GetCount() || requestedblocks_list.GetCount()){ 
@@ -1410,7 +1423,7 @@ void CPartFile::CompleteFile(bool bIsHashingDone){
 
 		CAddFileThread::AddFile(theApp.glob_prefs->GetTempDir(), partfileb, this);
 
-		free(partfileb);
+		delete[] partfileb;
 		return;
 	}
 	else{
@@ -1443,7 +1456,7 @@ BOOL CPartFile::PerformFileComplete()
 	partfilename[strlen(fullname)-4] = 0;	// assumes ".met" at the end
 	char* newfilename = nstrdup(GetFileName());
 	strcpy(newfilename, theApp.StripInvalidFilenameChars(newfilename));
-	char* newname = (char*)malloc(strlen(newfilename)+strlen(theApp.glob_prefs->GetCategory(GetCategory())->incomingpath)+MAX_PATH*2);	// ???
+	char* newname = new char[strlen(newfilename)+strlen(theApp.glob_prefs->GetCategory(GetCategory())->incomingpath)+MAX_PATH*2];	// ???
 	CString indir;
 	if(wxFileName::DirExists(theApp.glob_prefs->GetCategory(GetCategory())->incomingpath)) {
 		indir=theApp.glob_prefs->GetCategory(GetCategory())->incomingpath;
@@ -1502,10 +1515,10 @@ BOOL CPartFile::PerformFileComplete()
 			strTestName.Format("%s/%s(%d).%s", theApp.glob_prefs->GetIncomingDir(),
 				newfilename, namecount, min(ext + 1, newfilename + length));
 		} while(wxFileName::FileExists(strTestName));
-		free(newname);
+		delete[] newname;
 		newname = nstrdup(strTestName);
 	}
-	free(newfilename);
+	delete[] newfilename;
 
 	if ( !wxRenameFile(partfilename, newname) )
 	{
@@ -1517,8 +1530,8 @@ BOOL CPartFile::PerformFileComplete()
 #ifdef __DEBUG__
 			printf("warning: wxCopyFile() failed too\n");
 #endif
-			free(partfilename);
-			free(newname);
+			delete[] partfilename;
+			delete[] newname;
 			wxMutexGuiEnter();
 			theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_COMPLETIONFAILED),GetFileName());
 			wxMutexGuiLeave();
@@ -1547,10 +1560,10 @@ BOOL CPartFile::PerformFileComplete()
 		wxMutexGuiLeave();
 	}
 
-	free(partfilename);
-	free(fullname);
+	delete[] partfilename;
+	delete [] fullname;
 	fullname = newname;
-	free(directory);
+	delete[] directory;
 	directory = nstrdup(theApp.glob_prefs->GetCategory(m_category)->incomingpath);
 	SetPartFileStatus(PS_COMPLETE);
 	paused = false;
@@ -1567,7 +1580,7 @@ BOOL CPartFile::PerformFileComplete()
 	theApp.knownfiles->SafeAddKFile(this);
 	// remove the file from the suspended uploads list
 	theApp.uploadqueue->ResumeUpload(tmp_filehash);
-	((CKnownFile*)this)->SetAutoPriority(false) ; //UAP
+	SetAutoUpPriority(false);
 	theApp.downloadqueue->RemoveFile(this);
 	//theApp.xmuledlg->transferwnd.downloadlistctrl.UpdateItem(this);
 	wxMutexGuiEnter();
@@ -1760,13 +1773,8 @@ bool CPartFile::IsText()
 }
 
 
-void CPartFile::SetPriority(uint8 np){
-	//UAP
-	if (np == PR_AUTO)
-		SetAutoPriority(true) ;
-	else
-	priority = np;
-	//end UAP
+void CPartFile::SetDownPriority(uint8 np) {
+	m_iDownPriority = np;
 	theApp.downloadqueue->SortByPriority();
 	//theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
 	UpdateDisplayedInfo(true);
@@ -1942,13 +1950,26 @@ Packet*	CPartFile::CreateSrcInfoPacket(CUpDownClient* forClient){
 		if (cur_src->HasLowID())
 			continue;
 		// only send source which have needed parts for this client if possible
-		if (forClient->reqfile == this && forClient->GetPartStatus() && cur_src->GetPartStatus()){
+		uint8* srcstatus = cur_src->GetPartStatus();
+		if (srcstatus){
 			uint8* reqstatus = forClient->GetPartStatus();
-			uint8* srcstatus = cur_src->GetPartStatus();
-			for (int x = 0; x != GetPartCount(); x++){
-				if (srcstatus[x] && !reqstatus[x]){
-					bNeeded = true;
-					break;
+			if (reqstatus){
+				// only send sources which have needed parts for this client
+				for (int x = 0; x < GetPartCount(); x++){
+					if (srcstatus[x] && !reqstatus[x]){
+						bNeeded = true;
+						break;
+					}
+				}
+			}
+			else{
+				// if we don't know the need parts for this client, return any source
+				// currently a client sends it's file status only after it has at least one complete part,
+				for (int x = 0; x < GetPartCount(); x++){
+					if (srcstatus[x]){
+						bNeeded = true;
+						break;
+					}
 				}
 			}
 		}
@@ -1962,6 +1983,8 @@ Packet*	CPartFile::CreateSrcInfoPacket(CUpDownClient* forClient){
 			data.Write(&nPort, 2);
 			data.Write(&dwServerIP, 4);
 			data.Write(&nServerPort, 2);
+			if (forClient->GetSourceExchangeVersion()>1)
+				data.Write(cur_src->GetUserHash(), 16);
 			if (nCount > 500)
 				break;
 		}
@@ -1979,7 +2002,7 @@ Packet*	CPartFile::CreateSrcInfoPacket(CUpDownClient* forClient){
 	return result;
 }
 
-void CPartFile::AddClientSources(CMemFile* sources){
+void CPartFile::AddClientSources(CMemFile* sources,uint8 sourceexchangeversion){
 	if(stopped) return;
 	uint16 nCount;
 	sources->Read(&nCount,2);
@@ -1988,10 +2011,13 @@ void CPartFile::AddClientSources(CMemFile* sources){
 		uint16 nPort;
 		uint32 dwServerIP;
 		uint16 nServerPort;
+		uchar achUserHash[16];
 		sources->Read(&dwID,4);
 		sources->Read(&nPort,2);
 		sources->Read(&dwServerIP,4);
 		sources->Read(&nServerPort,2);
+		if ( sourceexchangeversion > 1 )
+			sources->Read(achUserHash, 16);
 		// check first if we are this source
 		if (theApp.serverconnect->GetClientID() < 16777216 && theApp.serverconnect->IsConnected()){
 			if ((theApp.serverconnect->GetClientID() == dwID) && theApp.serverconnect->GetCurrentServer()->GetIP() == dwServerIP)
@@ -2003,24 +2029,26 @@ void CPartFile::AddClientSources(CMemFile* sources){
 			continue;
 		if( theApp.glob_prefs->GetMaxSourcePerFile() > this->GetSourceCount() ){
 			CUpDownClient* newsource = new CUpDownClient(nPort,dwID,dwServerIP,nServerPort,this);
+			if (sourceexchangeversion > 1)
+				newsource->SetUserHash(achUserHash);
 			theApp.downloadqueue->CheckAndAddSource(this,newsource);
-		} 
+		}
+		else
+			break;
 	}
 }
-void CPartFile::UpdateUploadAutoPriority(void)
+
+void CPartFile::UpdateAutoDownPriority()
 {
-	if (this->IsAutoPrioritized()) {
-		CPartFile* partfile = theApp.downloadqueue->GetFileByID(this->GetFileHash()) ;
-		if (!partfile) return;
-		if (partfile->IsPartFile()) {
-			if (partfile->GetSourceCount() <= RARE_FILE)
-				this->SetPriority(PR_VERYHIGH) ;
-			else if (partfile->GetSourceCount() < 100)
-				this->SetPriority(PR_HIGH) ;
-			else
-				this->SetPriority(PR_NORMAL) ;
-		}
-	}
+	if (!IsAutoDownPriority())
+		return;
+
+	if (GetSourceCount() <= RARE_FILE)
+		SetDownPriority(PR_VERYHIGH);
+	else if (GetSourceCount() < 100)
+		SetDownPriority(PR_HIGH);
+	else
+		SetDownPriority(PR_NORMAL);
 }
 
 // making this function return a higher when more sources have the extended
