@@ -26,6 +26,7 @@
 #include "wx/dc.h"
 #include "wx/dcmemory.h"
 #include "wx/treectrl.h"
+#include "otherfunctions.h"
 
 #define	PS_READY			0
 #define	PS_EMPTY			1
@@ -42,7 +43,7 @@
 #define PR_NORMAL			1 // Don't change this - needed for edonkey clients and server!
 #define	PR_HIGH				2 //*
 #define PR_VERYHIGH			3
-#define PR_AUTO				5 //UAP Hunter
+#define PR_AUTO				5
 #define SRV_PR_LOW			2
 #define SRV_PR_NORMAL		0
 #define SRV_PR_HIGH			1
@@ -84,6 +85,7 @@ public:
 	void	AddGap(uint32 start, uint32 end);
 	void	FillGap(uint32 start, uint32 end);
 	void	DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool bFlat);
+	void	DrawShareStatusBar(wxMemoryDC* dc, wxRect rect, bool onlygreyrect, bool bFlat);
 	bool	IsComplete(uint32 start, uint32 end);
 	bool	IsPureGap(uint32 start, uint32 end);
 	bool	IsCorruptedPart(uint16 partnumber);
@@ -94,10 +96,8 @@ public:
 	void	AddSources(CMemFile* sources,uint32 serverip, uint16 serverport);
 	uint8	GetStatus(bool ignorepause = false);
 	void	NewSrcPartsInfo();
-	void	SetPriority(uint8 np);
 	char*	GetPartMetFileName()							{return partmetfilename;}
 	uint32	GetTransfered()									{return transfered;}
-	uint8	GetPriority()									{return priority;}
 	char*	GetFullName()									{return fullname;}
 	uint16	GetSourceCount();
 	uint16	GetTransferingSrcCount()						{return transferingsrc;}
@@ -140,7 +140,7 @@ public:
 	void	ResumeFile();
 
 	virtual	Packet* CreateSrcInfoPacket(CUpDownClient* forClient);
-	void	AddClientSources(CMemFile* sources);
+	void	AddClientSources(CMemFile* sources,uint8 sourceexchangeversion);
 
 	void	PreviewFile();
 	bool	PreviewAvailable();
@@ -172,11 +172,11 @@ public:
 
 	CFile	m_hpartfile;	//permanent opened handle to avoid write conflicts
 	volatile bool m_bPreviewing;
-	//UAP Hunter
-	void    UpdateUploadAutoPriority(void) ;
-	bool	IsAutoPrioritized() { return m_bAutoPriority ; }
-	void	SetAutoPriority(bool newAutoPriority) { this->m_bAutoPriority = newAutoPriority ; }
-	//end UAP
+	void	SetDownPriority(uint8 newDownPriority);
+	bool	IsAutoDownPriority()	{ return m_bAutoDownPriority; }
+	void	SetAutoDownPriority(bool flag) { m_bAutoDownPriority = flag; }
+	void	UpdateAutoDownPriority();
+	uint8	GetDownPriority()	{ return m_iDownPriority; }
 protected:
 	bool	GetNextEmptyBlockInPart(uint16 partnumber,Requested_Block_Struct* result);
 	bool	IsAlreadyRequested(uint32 start, uint32 end);
@@ -197,7 +197,8 @@ private:
 	uint32	transfered;
 	bool	paused;
 	bool	stopped;
-	uint8	priority;
+	uint8	m_iDownPriority;
+	bool	m_bAutoDownPriority;
 	uint8	status;
 	bool	newdate;	// indicates if there was a writeaccess to the .part file
 	uint32	lastsearchtime;
@@ -214,7 +215,6 @@ private:
 	bool	m_bPercentUpdated;
 	static	CBarShader s_LoadBar; 
 	static	CBarShader s_ChunkBar; 
-    bool	m_bAutoPriority ;	//UAP Hunter
 	bool	hasRating;
 	bool	hasComment;
 	BOOL 	PerformFileComplete(); // Lord KiRon
