@@ -338,7 +338,7 @@ void CQueueListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRec
     CString Sbuffer;
     //	char buffer[100];
     
-    CKnownFile* file = theApp.sharedfiles->GetFileByID(client->reqfileid);
+    CKnownFile* file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
     //CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
     int iCount =GetColumnCount();// pHeaderCtrl->GetItemCount();
     cur_rec.right = cur_rec.left - 8;
@@ -406,7 +406,7 @@ void CQueueListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRec
 	  break;
 	case 2:
 	  if(file){
-	    switch(file->GetPriority()){ 
+	    switch(file->GetUpPriority()){ 
 	    case PR_VERYHIGH:
 	      Sbuffer.Format("%s",GetResString(IDS_PRIORELEASE).GetData());
 	      break;
@@ -569,8 +569,8 @@ void CQueueListCtrl::OnColumnClick( wxListEvent& evt) {//NMHDR* pNMHDR, LRESULT*
 int CQueueListCtrl::SortProc(long lParam1, long lParam2, long lParamSort){
 	CUpDownClient* item1 = (CUpDownClient*)lParam1;
 	CUpDownClient* item2 = (CUpDownClient*)lParam2;
-	CKnownFile* file1 = theApp.sharedfiles->GetFileByID(item1->reqfileid);
-	CKnownFile* file2 = theApp.sharedfiles->GetFileByID(item2->reqfileid);
+	CKnownFile* file1 = theApp.sharedfiles->GetFileByID(item1->GetUploadFileID());
+	CKnownFile* file2 = theApp.sharedfiles->GetFileByID(item2->GetUploadFileID());
 		switch(lParamSort){
 		case 0: 
 			return CString(item1->GetUserName()).CmpNoCase(item2->GetUserName());
@@ -592,14 +592,14 @@ int CQueueListCtrl::SortProc(long lParam1, long lParam2, long lParamSort){
 				return 0;
 		case 2: 
 			if( (file1 != NULL) && (file2 != NULL))
-				return file1->GetPriority() - file2->GetPriority();
+				return file1->GetUpPriority() - file2->GetUpPriority();
 			else if( file1 == NULL )
 				return 1;
 			else
 				return 0;
 		case 102:
 			if( (file1 != NULL) && (file2 != NULL))
-				return file2->GetPriority() - file1->GetPriority();
+				return file2->GetUpPriority() - file1->GetUpPriority();
 			else if( file1 == NULL )
 				return 1;
 			else
