@@ -266,6 +266,8 @@ CSearchDlg::CSearchDlg(wxWindow* pParent /*=NULL*/)
     m_timer(this,ID_SEARCHTIMER)
 {
   m_nSearchID = 0;
+  global_search_timer = 0;
+  globsearch = false;
   
   searchpacket=NULL;
   searchprogress=NULL; // will be set later...
@@ -378,8 +380,11 @@ void CSearchDlg::OnBnClickedStarts(wxEvent& ev){
 	wxStringTokenizer tkz(ctl->GetValue(), "\r\n");
 #endif
 
+	bool bHadLink = false;
+
 	while (tkz.HasMoreTokens()) {
 		wxString strlink = tkz.GetNextToken();
+		bHadLink = true;
 
 		if(strlink.Right(1)!="/") { strlink+="/"; }
 		ctl->SetValue("");
@@ -398,6 +403,8 @@ void CSearchDlg::OnBnClickedStarts(wxEvent& ev){
 			theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_LINKERROR),buffer);
 		}
 	}
+	if ( bHadLink )
+		return;
 
 	// start a search
 	StartNewSearch();
