@@ -297,7 +297,7 @@ CKnownFile*	CSharedFileList::GetFileByID(uchar* filehash){
 short CSharedFileList::GetFilePriorityByID(uchar* filehash){
 	CKnownFile* tocheck = GetFileByID(filehash);
 	if (tocheck)
-		return tocheck->GetPriority();
+		return tocheck->GetUpPriority();
 	else
 		return -10;	// file doesn't exist
 }
@@ -358,3 +358,19 @@ wxThread::ExitCode CAddFileThread::Entry(){
 #endif
 
 void CSharedFileList::UpdateItem(CKnownFile* toupdate) {output->UpdateItem(toupdate);}
+
+void CSharedFileList::GetSharedFilesByDirectory(const char *directory,
+                            CTypedPtrList<CPtrList, CKnownFile*>& list)
+{
+	for (CKnownFileMap::iterator pos = m_Files_map.begin();
+	     pos != m_Files_map.end(); pos++ ) {
+		CKnownFile *cur_file = pos->second;
+
+		if ( 0 != strcmp(cur_file->GetPath(), directory) )
+			continue;
+
+		list.AddTail(cur_file);
+	}
+}
+
+
