@@ -39,7 +39,7 @@ END_EVENT_TABLE()
 CSharedFilesWnd::CSharedFilesWnd(wxWindow* pParent /*=NULL*/)
 	: wxPanel(pParent,CSharedFilesWnd::IDD)
 {
-	//shownFileHash[0]=0;
+  memset(shownFileHash,0,sizeof shownFileHash);
   SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWFRAME));
   wxSizer* content=sharedfilesDlg(this,TRUE);
   content->Show(this,TRUE);
