@@ -251,7 +251,7 @@ void CUploadListCtrl::RefreshClient(CUpDownClient* client){
   //SetItem(itemnr,0,LVIF_IMAGE,0,image,0,0,0,0);
 #warning Image is not added
   char buffer[100];
-  CKnownFile* file = theApp.sharedfiles->GetFileByID(client->reqfileid);
+  CKnownFile* file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
   if (file)
     SetItem(itemnr,1,file->GetFileName());
   else
@@ -377,8 +377,8 @@ void CUploadListCtrl::OnColumnClick( wxListEvent& evt) { //NMHDR* pNMHDR, LRESUL
 int CUploadListCtrl::SortProc(long lParam1, long lParam2, long lParamSort){
 	CUpDownClient* item1 = (CUpDownClient*)lParam1;
 	CUpDownClient* item2 = (CUpDownClient*)lParam2;
-	CKnownFile* file1 = theApp.sharedfiles->GetFileByID(item1->reqfileid);
-	CKnownFile* file2 = theApp.sharedfiles->GetFileByID(item2->reqfileid);
+	CKnownFile* file1 = theApp.sharedfiles->GetFileByID(item1->GetUploadFileID());
+	CKnownFile* file2 = theApp.sharedfiles->GetFileByID(item2->GetUploadFileID());
 		switch(lParamSort){
 		case 0: 
 			return CString(item1->GetUserName()).CmpNoCase(item2->GetUserName());
@@ -434,7 +434,7 @@ int CUploadListCtrl::SortProc(long lParam1, long lParam2, long lParamSort){
 void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRect& rectHL,bool highlighted)
 {
 	/* Don't do any drawing if we not being watched. */
-	if ((theApp.xmuledlg->transferwnd->windowtransferstate) || (theApp.xmuledlg->GetActiveDialog() != 2)) {
+	if (!theApp.xmuledlg->IsRunning() || (theApp.xmuledlg->transferwnd->windowtransferstate) || (theApp.xmuledlg->GetActiveDialog() != 2)) {
 		return;
 	}
 
@@ -486,7 +486,7 @@ void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRe
     // end lagloose
 
     CString Sbuffer;
-    CKnownFile* file = theApp.sharedfiles->GetFileByID(client->reqfileid);
+    CKnownFile* file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
     //CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
     int iCount = GetColumnCount(); //pHeaderCtrl->GetItemCount();
     cur_rec.right = cur_rec.left - 8;
