@@ -84,13 +84,13 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 			waitinglist.GetNext(pos1);
 			CUpDownClient* cur_client =	waitinglist.GetAt(pos2);
 			// clear dead clients
-			if ((::GetTickCount() - cur_client->GetLastUpRequest() > MAX_PURGEQUEUETIME) || !theApp.sharedfiles->GetFileByID(cur_client->reqfileid) ){
+			if ((::GetTickCount() - cur_client->GetLastUpRequest() > MAX_PURGEQUEUETIME) || !theApp.sharedfiles->GetFileByID(cur_client->GetUploadFileID()) ){
 				RemoveFromWaitingQueue(pos2,true);	
 				if (!cur_client->socket)
 					cur_client->Disconnected();
 			}
 			// Banned client or suspended upload ? 
-			else if (cur_client->IsBanned() || suspended_uploads_list.Find(cur_client->reqfileid)) 
+			else if (cur_client->IsBanned() || suspended_uploads_list.Find(cur_client->GetUploadFileID())) 
 			        continue;
 			// finished clearing
 			else if ( (cur_client->GetScore(true) > bestscore) 
@@ -107,7 +107,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 	}
 	else {
 		//prevent another potential access of a suspended upload
-		if(suspended_uploads_list.Find(directadd->reqfileid))
+		if(suspended_uploads_list.Find(directadd->GetUploadFileID()))
 			return;
 		else
 			newclient = directadd;
@@ -189,7 +189,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 		 (newclient->m_clientModString.Cmp("Mison") == 0 ) ||
 	     (newclient->m_clientModString.Cmp("SpeedLoad") == 0 ) ||
 		 (newclient->m_clientModString.Cmp("|X|") == 0 ) ||
-		 ((newclient->m_clientModString.IsEmpty() == false) && (newclient->GetClientSoft() != SO_EMULE)) ||
+		 ((newclient->m_clientModString.IsEmpty() == false) && (newclient->GetClientSoft() != SO_EMULE) && (newclient->GetClientSoft() != SO_xmule) ) ||
 		 ((!newclient->GetMuleVersion() && (newclient->GetClientSoft()==SO_EMULE || newclient->GetClientSoft()==SO_OLDEMULE)) && (newclient->GetVersion()==60 || !newclient->GetVersion())) ||
 		 (!newclient->ExtProtocolAvailable() && newclient->GetClientSoft()==SO_EMULE && (newclient->GetVersion()==60 || !newclient->GetVersion())) ||
 		 ((newclient->GetVersion()>589) && (newclient->GetSourceExchangeVersion()>0) && (newclient->GetClientSoft()== SO_EDONKEY)))	 	 
@@ -221,7 +221,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 	uploadinglist.AddTail(newclient);
 	
 	// statistic
-	CKnownFile* reqfile = theApp.sharedfiles->GetFileByID((uchar*)newclient->reqfileid);
+	CKnownFile* reqfile = theApp.sharedfiles->GetFileByID((uchar*)newclient->GetUploadFileID());
 	if (reqfile)
 		reqfile->statistic.AddAccepted();
 	
@@ -324,7 +324,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 			// FooMan: Additional restriction added to prevent upload of files on suspended_uploads_list
 			else if ( ( (cur_client->GetScore(true) > bestscore) && (!cur_client->IsBanned()) 
 				&& (!cur_client->HasLowID() || (cur_client->socket && cur_client->socket->IsConnected()) ) )
-				&& (!suspended_uploads_list.Find(cur_client->reqfileid) ) ){
+				&& (!suspended_uploads_list.Find(cur_client->GetUploadFileID()) ) ){
 				bestscore = cur_client->GetScore(true);
 				toadd = pos2;
 			}
@@ -355,7 +355,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient* directadd){
 	uploadinglist.AddTail(newclient);
 	
 	// statistic
-	CKnownFile* reqfile = theApp.sharedfiles->GetFileByID((uchar*)newclient->reqfileid);
+	CKnownFile* reqfile = theApp.sharedfiles->GetFileByID((uchar*)newclient->GetUploadFileID());
 	if (reqfile)
 		reqfile->statistic.AddAccepted();
 	
@@ -492,7 +492,7 @@ void CUploadQueue::AddClientToQueue(CUpDownClient* client, bool bIgnoreTimelimit
 			else
 				return;
 		}
-		client->AddRequestCount(client->reqfileid);
+		client->AddRequestCount(client->GetUploadFileID());
 	}
 	// check for double
 	for (POSITION pos = waitinglist.GetHeadPosition();pos != 0;waitinglist.GetNext(pos)){
@@ -527,7 +527,7 @@ void CUploadQueue::AddClientToQueue(CUpDownClient* client, bool bIgnoreTimelimit
 	}
 
 	// statistic values
-	CKnownFile* reqfile = theApp.sharedfiles->GetFileByID((uchar*)client->reqfileid);
+	CKnownFile* reqfile = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
 		if (reqfile)
 			reqfile->statistic.AddRequest();
 	// TODO find better ways to cap the list
@@ -759,14 +759,14 @@ void CUploadQueue::FindSourcesForFileById(CTypedPtrList<CPtrList, CUpDownClient*
 	pos = uploadinglist.GetHeadPosition();
 	while(pos) {
 		CUpDownClient *potential = uploadinglist.GetNext(pos);
-		if(memcmp(potential->reqfileid, filehash, 16) == 0)
+		if(memcmp(potential->GetUploadFileID(), filehash, 16) == 0)
 			srclist->AddTail(potential);
 	}
 
 	pos = waitinglist.GetHeadPosition();
 	while(pos) {
 		CUpDownClient *potential = waitinglist.GetNext(pos);
-		if(memcmp(potential->reqfileid, filehash, 16) == 0)
+		if(memcmp(potential->GetUploadFileID(), filehash, 16) == 0)
 			srclist->AddTail(potential);
 	}
 }
@@ -786,7 +786,7 @@ void CUploadQueue::SuspendUpload( const CFileHash& filehash )
 	while(pos) { //while we have a valid position
 		CUpDownClient *potential = uploadinglist.GetNext(pos);
 		//check if the client is uploading the file we need to suspend
-		if(memcmp(potential->reqfileid, filehash, 16) == 0) {
+		if(memcmp(potential->GetUploadFileID(), filehash, 16) == 0) {
 			//remove the unlucky client from the upload queue and add to the waiting queue
 			RemoveFromUploadQueue(potential, 1);
 			printf("%s: Removed user '%s'\n", base16hash.GetBuffer() ,potential->GetUserName() );
