@@ -1049,10 +1049,10 @@ wxString CWebServer::_GetTransferList(ThreadData Data)
 	{
 		wxString JSfileinfo=FilesArray[i]->sFileInfo;
 		JSfileinfo.Replace("\n","\\n");
-		wxString sActions = "<acronym title=\"" + FilesArray[i]->sFileStatus + "\"><a href=\"javascript:alert(\'"+ JSfileinfo+"')\"><img src=\"javascript:img_info\" alt=\"" + FilesArray[i]->sFileStatus + "\"></a></acronym> ";
+		wxString sActions = "<acronym title=\"" + FilesArray[i]->sFileStatus + "\"><a href=\"javascript:alert(\'"+ JSfileinfo+"')\"><img src=\"l_info.gif\" alt=\"" + FilesArray[i]->sFileStatus + "\"></a></acronym> ";
 
 		wxString sED2kLink;
-		sED2kLink.Printf("<acronym title=\"[Ed2klink]\"><a href=\""+ FilesArray[i]->sED2kLink +"\"><img src=\"javascript:img_link\" alt=\"[Ed2klink]\"></a></acronym> ");
+		sED2kLink.Printf("<acronym title=\"[Ed2klink]\"><a href=\""+ FilesArray[i]->sED2kLink +"\"><img src=\"l_ed2klink.gif\" alt=\"[Ed2klink]\"></a></acronym> ");
 		sED2kLink.Replace("[Ed2klink]", _GetPlainResString(IDS_SW_LINK));
 		sActions += sED2kLink;
 
@@ -1070,7 +1070,7 @@ wxString CWebServer::_GetTransferList(ThreadData Data)
 		case PS_PAUSED:
 		{
 			wxString sResume;
-			sResume.Printf("<acronym title=\"[Resume]\"><a href=\"[Link]\"><img src=\"javascript:img_resume\" alt=\"[Resume]\"></a></acronym> ");
+			sResume.Printf("<acronym title=\"[Resume]\"><a href=\"[Link]\"><img src=\"l_resume.gif\" alt=\"[Resume]\"></a></acronym> ");
 			
 			sResume.Replace("[Link]", IsSessionAdmin(Data,sSession)?wxString("/?ses=" + sSession + "&w=transfer&op=resume&file=" + FilesArray[i]->sFileHash):GetPermissionDenied()) ;
 			
@@ -1080,7 +1080,7 @@ wxString CWebServer::_GetTransferList(ThreadData Data)
 		default: // waiting or downloading
 		{
 			wxString sPause;
-			sPause.Printf("<acronym title=\"[Pause]\"><a href=\"[Link]\"><img src=\"javascript:img_pause\" alt=\"[Pause]\"></a></acronym> ");
+			sPause.Printf("<acronym title=\"[Pause]\"><a href=\"[Link]\"><img src=\"l_pause.gif\" alt=\"[Pause]\"></a></acronym> ");
 			sPause.Replace("[Link]", IsSessionAdmin(Data,sSession)?wxString("/?ses=" + sSession + "&w=transfer&op=pause&file=" + FilesArray[i]->sFileHash):GetPermissionDenied());
 			sActions += sPause;
 		}
@@ -1089,7 +1089,7 @@ wxString CWebServer::_GetTransferList(ThreadData Data)
 		if(bCanBeDeleted)
 		{
 			wxString sCancel;
-			sCancel.Printf("<acronym title=\"[Cancel]\"><a href=\"[Link]\" onclick=\"return confirm(\'[ConfirmCancel]\')\"><img src=\"javascript:img_cancel\" alt=\"[Cancel]\"></a></acronym> ");
+			sCancel.Printf("<acronym title=\"[Cancel]\"><a href=\"[Link]\" onclick=\"return confirm(\'[ConfirmCancel]\')\"><img src=\"l_cancel.gif\" alt=\"[Cancel]\"></a></acronym> ");
 			sCancel.Replace("[Link]", IsSessionAdmin(Data,sSession)?wxString("/?ses=" + sSession + "&w=transfer&op=cancel&file=" + FilesArray[i]->sFileHash):GetPermissionDenied());
 			sActions += sCancel;
 		}
@@ -1231,8 +1231,8 @@ wxString CWebServer::_GetTransferList(ThreadData Data)
             char HTTPTempC[100] = "";
 			HTTPProcessData = OutE;
 			HTTPProcessData.Replace("[UserName]", _SpecialChars(cur_client->GetUserName()));
-			if (cur_client->reqfile)
-				HTTPProcessData.Replace("[FileName]", _SpecialChars(cur_client->reqfile->GetFileName()));
+			if (cur_client->GetDownloadFile())
+				HTTPProcessData.Replace("[FileName]", _SpecialChars(cur_client->GetDownloadFile()->GetFileName()));
 			else
 				HTTPProcessData.Replace("[FileName]", "?");
 			sprintf(HTTPTempC, "%i" , cur_client->GetScore(false));
@@ -1572,7 +1572,7 @@ wxString CWebServer::_GetSharedFilesList(ThreadData Data)
 		else
 			HTTPProcessData.Replace("[ShortFileName]", _SpecialChars(SharedArray[i]->sFileName));
 
-		sprintf(HTTPTempC, "%s %s",CastItoXBytes(SharedArray[i]->lFileSize).GetData(), _GetPlainResString(IDS_MBYTES).GetData());
+		sprintf(HTTPTempC, "%s",CastItoXBytes(SharedArray[i]->lFileSize).GetData());
 		HTTPProcessData.Replace("[FileSize]", wxString(HTTPTempC));
 
 		HTTPProcessData.Replace("[FileLink]", SharedArray[i]->sED2kLink);
