@@ -17,17 +17,17 @@
 
 #ifndef _OPCODES_H
 #ifndef _DUMP
-	#define CURRENT_VERSION_LONG	"0.26d"
+	#define CURRENT_VERSION_LONG	"0.27a"
 #else
-	#define CURRENT_VERSION_LONG	"0.26d DEBUG"
+	#define CURRENT_VERSION_LONG	"0.27a DEBUG"
 #endif
 #define WM_APP 5500
 
 #define MOD_VERSION             "xMule"
 #define ET_MOD_VERSION 			0x55
 // MOD Note: Do not change this part - Merkur
-#define CURRENT_VERSION_SHORT	0x26
-#define CURRENT_VERSION_CHECK	0x26D
+#define CURRENT_VERSION_SHORT	0x30
+#define CURRENT_VERSION_CHECK	0x30
 #define	EMULE_PROTOCOL			0x01
 // MOD Note: end
 #define	EDONKEYVERSION			0x3c
@@ -131,9 +131,13 @@
 #define OP_GLOBSEARCHRES		0x99	// 
 #define OP_GLOBGETSOURCES		0x9A	// <HASH 16>
 #define OP_GLOBFOUNDSORUCES		0x9B	//
-#define OP_GLOBCALLBACKREQ		0x9C	// <ID 4>
-#define OP_UNKNOWN1				0xA2	//
-#define OP_UNKNOWN2				0xA4	//
+#define OP_GLOBCALLBACKREQ		0x9C	// <IP 4><PORT 2><client_ID 4>
+#define OP_INVALID_LOWID		0x9E	// <ID 4>
+#define	OP_SERVER_LIST_REQ		0xA0	// <IP 4><PORT 2>
+#define OP_SERVER_LIST_RES		0xA1	// <count 1> (<ip 4><port 2>)[count]
+#define OP_SERVER_DESC_REQ		0xA2	// (null)
+#define OP_SERVER_DESC_RES		0xA3	// <name_len 2><name name_len><desc_len 2 desc_en>
+#define OP_SERVER_LIST_REQ2		0xA4	// (null)
 
 // client <-> client
 #define	OP_HELLO				0x01	// 0x10<HASH 16><ID 4><PORT 2><1 Tag_set>
@@ -158,6 +162,12 @@
 #define OP_FILEREQANSWER		0x59	// <HASH 16><len 4><NAME len>
 #define OP_CHANGE_SLOT			0x5B	// <HASH 16>
 #define OP_QUEUERANK			0x5C	// <wert  4> (slot index of the request)
+#define OP_ASKSHAREDDIRS        0x5D    // (null)
+#define OP_ASKSHAREDFILESDIR    0x5E    // <len 2><Directory len>
+#define OP_ASKSHAREDDIRSANS     0x5F    // <count 4>(<len 2><Directory len>)[count]
+#define OP_ASKSHAREDFILESDIRANS 0x60    // <len 2><Directory len><count 4>(<HASH 16><ID 4><PORT 2><1 Tag_set>)[count]
+#define OP_ASKSHAREDDENIEDANS   0x61    // (null)
+
 
 
 // extened prot client <-> extened prot client
@@ -175,9 +185,9 @@
 
 // extened prot client <-> extened prot client UDP
 #define OP_REASKFILEPING		0x90	// <HASH 16>
-#define OP_REASKACK				0x91	// <HASH 16>
-#define OP_FILENOTFOUND			0x92
-#define OP_QUEUEFULL			0x93
+#define OP_REASKACK				0x91	// <RANG 2>
+#define OP_FILENOTFOUND			0x92	// (null)
+#define OP_QUEUEFULL			0x93	// (null)
 	
 // server.met
 #define ST_SERVERNAME			0x01	// <string>
@@ -200,17 +210,21 @@
 #define FT_GAPSTART				0x09
 #define FT_GAPEND				0x0A
 #define FT_PARTFILENAME			0x12	// <string>
-#define FT_PRIORITY				0x13
+#define FT_OLDDLPRIORITY			0x13
 #define FT_STATUS				0x14
 #define FT_SOURCES				0x15
 #define FT_PERMISSIONS			0x16
-#define FT_ULPRIORITY			0x17
+#define FT_OLDULPRIORITY			0x17
 #define FT_CATEGORY 			0x53
+#define FT_DLPRIORITY			0x18	// Was 13
+#define FT_ULPRIORITY			0x19	// Was 17
+
 
 // statistic
 #define FT_ATTRANSFERED			0x50
 #define FT_ATREQUESTED			0x51
 #define FT_ATACCEPTED			0x52
+#define	FT_ATTRANSFEREDHI		0x54
 
 #define CT_NAME					0x01
 #define CT_VERSION				0x11
@@ -294,7 +308,7 @@
 #define ET_SOURCEEXCHANGE		0x23
 #define ET_COMMENTS				0x24
 #define ET_EXTENDEDREQUEST		0x25
-#define ET_COMPATABLECLIENT		0x26
+#define ET_COMPATABLECLIENT		0x30
 #define ET_FEATURES			0x27	// bit 0: SecIdent v1
 						// bit 1: SecIdent v2
 
