@@ -101,6 +101,7 @@ public:
 	uint32			GetServerIP()				{return m_dwServerIP;}
 	uint16			GetServerPort()				{return m_nServerPort;}
 	uchar*			GetUserHash()				{return (uchar*)m_achUserHash;}
+	void			SetUserHash(uchar* achUserHash)		{if(achUserHash) memcpy(m_achUserHash,achUserHash,16); else memset(m_achUserHash,0,16); }
 	bool			HasValidHash()				{return ((int*)m_achUserHash)[0] != 0 || ((int*)m_achUserHash)[1] != 0 ||
 												        ((int*)m_achUserHash)[2] != 0 || ((int*)m_achUserHash)[3] != 0; }
 	uint32			GetVersion()				{return m_nClientVersion;}
@@ -164,7 +165,10 @@ public:
 	uint32			GetUpStartTimeDelay()		{return ::GetTickCount() - m_dwUploadTime;}
 	void			SetWaitStartTime(uint32 dwTime = 0);
 	void			SendHashsetPacket(char* forfileid);
-	uchar			reqfileid[16];
+	void			SetUploadFileID(uchar* tempreqfileid);
+	uchar*			GetUploadFileID()	{return requpfileid;}
+	CPartFile*		GetDownloadFile()	{return reqfile;}
+	void			SetDownloadFile(CPartFile*);
 	uint32			SendBlockData(uint32 maxammount);
 	void			ClearUploadBlockRequests();
 	void			SendRankingInfo();
@@ -195,7 +199,9 @@ public:
 	uint8			GetDownloadState()			{return m_nDownloadState;}
 	void			SetDownloadState(uint8 byNewState);
 	uint32			GetLastAskedTime()			{return m_dwLastAskedTime;}
-	inline bool			IsPartAvailable(uint16 iPart)	{return	( (iPart >= m_nPartCount) || (!m_abyPartStatus) )? 0:m_abyPartStatus[iPart];} 	
+	inline bool			IsPartAvailable(uint16 iPart)	{return	( (iPart >= m_nPartCount) || (!m_abyPartStatus) )? 0:m_abyPartStatus[iPart];}
+	bool			IsUpPartAvailable(uint16 iPart) {return ( (iPart
+ >= m_nUpPartCount) || (!m_abyUpPartStatus) )? 0:m_abyUpPartStatus[iPart];}
 	uint8*			GetPartStatus()				{return m_abyPartStatus;}
 	uint32			GetDownloadDatarate()		{return m_nDownDatarate;}
 	uint16			GetRemoteQueueRank()		{return m_nRemoteQueueRank;}
@@ -219,7 +225,6 @@ public:
 	void			UDPReaskForDownload();
 	bool			IsSourceRequestAllowed();
 	
-	CPartFile*		reqfile;
 	int				sourcesslot;
 
 	//chat
@@ -237,7 +242,12 @@ public:
 	// Barry - Sets string to show parts downloading, eg NNNYNNNNYYNYN
 	void ShowDownloadingParts(CString *partsYN);
 	void UpdateDisplayedInfo(bool force=false);
+	int  GetFileListRequested() { return m_iFileListRequested; }
+	void SetFileListRequested(int iFileListRequested) { m_iFileListRequested = iFileListRequested; }
+
 private:
+	CPartFile*		reqfile;
+
 	// base
 	void	Init();
 	void	ProcessHelloTypePacket(CSafeMemFile* data);
@@ -268,7 +278,7 @@ private:
 	uint8	m_clientSoft;
 	uint32	m_dwLastSourceRequest;
 	uint32	m_dwLastSourceAnswer;
-	bool	m_bFileListRequested;
+	int	m_iFileListRequested;
 	bool	m_bFriendSlot;
 	bool	m_bCommentDirty;
 	bool	m_bIsHybrid;
@@ -294,6 +304,7 @@ private:
 	uint32		m_nCurSessionUp;
 	uint16		m_nUpPartCount;
 	static		CBarShader s_UpStatusBar;
+	uchar		requpfileid[16];
 	public:
 	uint8*		m_abyUpPartStatus;
 	uint32		m_nSumForAvgUpDataRate;
@@ -325,6 +336,7 @@ private:
 	bool		m_bReaskPending;
 	bool		m_bUDPPending;
 	uint32		m_nSumForAvgDownDataRate;
+	bool		m_bHashsetRequested;
 
 	CList<int,int>									 m_AvarageDDR_list;
 	CTypedPtrList<CPtrList, Pending_Block_Struct*>	 m_PendingBlocks_list;
