@@ -91,7 +91,9 @@ CxmuleApp::CxmuleApp()
 
 CxmuleApp::~CxmuleApp()
 {
+	delete listensocket;
 }
+
 int CxmuleApp::OnExit()
 {
 	/*
@@ -134,6 +136,8 @@ int CxmuleApp::OnExit()
 #endif
 
 	printf("xMule shutdown completed.\n");
+
+	return wxApp::OnExit();
 }
 
 
@@ -797,7 +801,7 @@ void CxmuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 	delete[] emulesig_path;
 	delete[] xmulesig_path;
 } //End Added By Bouc7
-#if defined(__Linux__)
+#if defined(__linux__)
 #include <execinfo.h>
 #endif
 
@@ -810,7 +814,7 @@ void CxmuleApp::OnFatalException()
 		theApp.clientudp->Destroy();
 
 	// (stkn) create backtrace
-#if defined(__Linux__)
+#if defined(__linux__)
 	void *bt_array[100];	// 100 should be enough ?!?
 	char **bt_strings;
 	int num_entries;
